@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  authentication mechanisms
@@ -36,7 +35,7 @@
 
 
 import traceback
-from typing import Any, Dict, Optional, Union  # noqa: F401
+from typing import Any
 
 import ldap
 from ldap.filter import filter_format
@@ -50,16 +49,16 @@ from univention.management.console.pam import (
 )
 
 
-class AuthenticationResult(object):
+class AuthenticationResult:
 
-    def __init__(self, result, locale):  # type: (Union[BaseException, Dict[str, str]], Optional[str]) -> None
+    def __init__(self, result: BaseException | dict[str, str], locale: str | None) -> None:
         self.credentials = None
         self.status = 200
         self.authenticated = not isinstance(result, BaseException)
         if self.authenticated:
             self.credentials = result
         self.message = None
-        self.result = None  # type: Optional[Dict[str, Any]]
+        self.result: dict[str, Any] | None = None
         self.password_expired = False
         if isinstance(result, AuthenticationError):
             self.status = 401
@@ -79,13 +78,13 @@ class AuthenticationResult(object):
         else:
             self.result = {'username': result['username']}
 
-    def __bool__(self):  # type: () -> bool
+    def __bool__(self) -> bool:
         return self.authenticated
 
     __nonzero__ = __bool__  # Python 2
 
 
-class AuthHandler(object):
+class AuthHandler:
 
     def get_handler(self, locale):
         # PAM MUST be initialized outside of a thread. Otherwise it segfaults e.g. with pam_saml.so.
@@ -137,7 +136,7 @@ class AuthHandler(object):
             AUTH.info('Authentication for %r was successful' % (username,))
             return (username, password)
 
-    def __canonicalize_username(self, username):  # type: (str) -> str
+    def __canonicalize_username(self, username: str) -> str:
         try:
             lo, _po = get_machine_connection(write=False)
             result = None
