@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  UMC configuration
@@ -79,5 +78,5 @@ env_to_settings = {
     SQL_POOL_SIZE_ENV_VAR: (SQL_POOL_SIZE_SETTINGS_NAME, '5'),
     SQL_MAX_OVERFLOW_ENV_VAR: (SQL_MAX_OVERFLOW_SETTINGS_NAME, '10'),
     SQL_POOL_TIMEOUT_ENV_VAR: (SQL_POOL_TIMEOUT_SETTINGS_NAME, '30'),
-    SQL_POOL_RECYCLE_ENV_VAR: (SQL_POOL_RECYCLE_SETTINGS_NAME, '-1')
+    SQL_POOL_RECYCLE_ENV_VAR: (SQL_POOL_RECYCLE_SETTINGS_NAME, '-1'),
 }
