@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  Base class for UMC 2.0 modules
@@ -36,4 +35,4 @@
 
 __path__ = __import__("pkgutil").extend_path(__path__, __name__)  # type: ignore
 
-from univention.management.console.base import *  # noqa: F401,F403
+from univention.management.console.base import *  # noqa: E402,F401,F403
