@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  Decorators for functions in UMC 2.0 modules
@@ -61,8 +60,9 @@ import sys
 import time
 import traceback
 import types
+from collections.abc import Callable  # noqa: F401
 from threading import Lock, Thread
-from typing import Any, Callable, Dict, Generic, List, Optional, Tuple, Type, TypeVar, Union  # noqa: F401
+from typing import TypeVar
 
 import tornado
 
@@ -205,7 +205,7 @@ def sanitize_args(sanitizer, name, args):
         raise UnprocessableEntity(str(exc), result=exc.result())
 
 
-class SimpleThread(object):
+class SimpleThread:
     """
     A simple class to start a thread and getting notified when the
     thread is finished. Meaning this class helps to handle threads that
@@ -577,7 +577,7 @@ def _eval_simple_decorated_function(function, with_flavor, single_values=False,
             if progress is True:
                 progress_title = None
             else:
-                if isinstance(progress, (list, tuple)):
+                if isinstance(progress, list | tuple):
                     progress_title, progress_msg = progress
                 else:
                     progress_title, progress_msg = progress, None
@@ -603,7 +603,7 @@ def _eval_simple_decorated_function(function, with_flavor, single_values=False,
     return _response
 
 
-class RequestOptionsIterator(object):
+class RequestOptionsIterator:
 
     def __init__(self, everything, names, single_values):
         self.everything = everything
@@ -778,7 +778,7 @@ def file_upload(function):
     return _response
 
 
-class reloading_ucr(object):
+class reloading_ucr:
 
     _last_reload = {}
 
