@@ -57,7 +57,7 @@ from univention.management.console.session_db import DBDisabledException, get_se
 from univention.management.console.shared_memory import shared_memory
 
 
-class OIDCUser(object):
+class OIDCUser:
     """OIDC tokens of the authenticated user."""
 
     __slots__ = ('access_token', 'claims', 'id_token', 'refresh_token', 'session_refresh_future', 'username')
@@ -72,7 +72,8 @@ class OIDCUser(object):
 
     @property
     def session_end_time(self):
-        exp = jwt.decode(self.refresh_token, verify=False)['exp'] if self.refresh_token else self.claims['exp']
+        # We can't verify the refresh token here, maybe we should get the session expiry from the token response instead
+        exp = jwt.decode(self.refresh_token, options={"verify_signature": False})['exp'] if self.refresh_token else self.claims['exp']
         return int(monotonic() + (exp - time.time()))
 
     @property
@@ -86,7 +87,7 @@ class OIDCResource(OAuth2Mixin, Resource):
     requires_authentication = False
 
     async def prepare(self):
-        await super(OIDCResource, self).prepare()
+        await super().prepare()
         state = shared_memory.pkce.get(self.get_query_argument('state', ''), {})
         self.set_settings(state.get('iss', self.get_query_argument('iss', self.application.settings['default_authorization_server'])))
 
@@ -339,6 +340,8 @@ class OIDCResource(OAuth2Mixin, Resource):
             )
         except HTTPClientError:
             raise  # handled in get()
+        # TODO why do we need that, see univention/ucs#2388
+        http_client.close()
         return escape.json_decode(response.body)
 
     async def refresh_session_tokens(self, user):
@@ -353,7 +356,7 @@ class OIDCResource(OAuth2Mixin, Resource):
             json_response = escape.json_decode(exc.response.body)
             if json_response.get('error') == 'invalid_grant':
                 if user.session_id in Session.sessions:
-                    Session.sessions[user.session_id].logout()
+                    Session.sessions[user.session_id].logout(reload=False)
             CORE.error('Could not get new access token: %s' % (json_response))
             raise OpenIDProvideUnavailable(self._('Could not receive token from authorization server.'))
 
@@ -467,6 +470,7 @@ class OIDCLogout(_OIDCLogoutBase):
         logout_url = '%s?%s' % (self._OAUTH_END_SESSION_URL, urlencode({
             'post_logout_redirect_uri': self.reverse_abs_url('oidc-logout-done'),
             'client_id': self.client_id,
+            'id_token_hint': user.oidc.id_token,
             # 'logout_hint': None,
             # 'ui_locales': None,
         }))
@@ -518,7 +522,10 @@ class OIDCFrontchannelLogout(_OIDCLogoutBase):
         self.add_header('Cache-Control', 'no-store')
         # self.get_query_argument('iss')
         # sid = self.get_query_argument('sid')
-        return self._logout_success()
+        user = self.current_user
+        if user:
+            user.oidc = None
+        self.expire_session()
 
 
 class OIDCBackchannelLogout(OIDCResource):
