@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #
@@ -35,7 +34,7 @@
 
 import re
 import traceback
-from typing import Any, Dict, Iterator, List, Optional, Pattern, Sequence, Tuple, Union  # noqa: F401
+from collections.abc import Iterator, Sequence  # noqa: F401
 
 from PAM import (
     PAM_ACCT_EXPIRED, PAM_AUTH_ERR, PAM_AUTHTOK_ERR, PAM_AUTHTOK_RECOVER_ERR, PAM_CONV, PAM_ERROR_MSG,
@@ -78,7 +77,7 @@ class AuthenticationInformationMissing(AuthenticationError):
 
     def __init__(self, message, missing_prompts):  # type: (str, Any) -> None
         self.missing_prompts = missing_prompts
-        super(AuthenticationInformationMissing, self).__init__(message)
+        super().__init__(message)
 
 
 class AccountExpired(AuthenticationError):
@@ -93,7 +92,7 @@ class PasswordChangeFailed(AuthenticationError):
     pass
 
 
-class PamAuth(object):
+class PamAuth:
 
     _known_errors = {
         'Make sure the kerberos service is functioning or inform an Administrator.': [
