@@ -1,7 +1,7 @@
 import os
 import time
+from collections.abc import Generator
 from contextlib import contextmanager
-from typing import Generator, Union
 
 from sqlalchemy import BigInteger, Column, String, create_engine, text
 from sqlalchemy.engine import Connection, Engine
@@ -60,7 +60,7 @@ class DBRegistry:
             'pool_size': int(os.environ.get(SQL_POOL_SIZE_ENV_VAR)),
             'max_overflow': int(os.environ.get(SQL_MAX_OVERFLOW_ENV_VAR)),
             'pool_timeout': int(os.environ.get(SQL_POOL_TIMEOUT_ENV_VAR)),
-            'pool_recycle': int(os.environ.get(SQL_POOL_RECYCLE_ENV_VAR))
+            'pool_recycle': int(os.environ.get(SQL_POOL_RECYCLE_ENV_VAR)),
         }
 
         url = make_url(connection_uri)
@@ -90,7 +90,7 @@ class PostgresListener:
         self.engine = engine
         self.conn = engine.connect()
 
-    def verify_postgres(self, engine: Union[Engine, None] = None):
+    def verify_postgres(self, engine: Engine | None = None):
         if engine is None:
             engine = self.engine
         if not self.engine.dialect.dialect_description == 'postgresql+psycopg2':
@@ -115,7 +115,7 @@ class PostgresListener:
                 notifier.set()
 
     @classmethod
-    def notify(cls, conn: Union[Connection, Session], session_id: str):
+    def notify(cls, conn: Connection | Session, session_id: str):
         if isinstance(conn, Session):
             connection = conn.connection()
         else:
@@ -198,5 +198,4 @@ class DBSession(Base):
             yield oidc_sessions_by_sid
         else:
             oidc_sessions_by_sub = db_session.query(cls).filter(cls.oidc_iss == claims.get('iss'), cls.oidc_sub == claims.get('sub')).all()
-            for oidc_session in oidc_sessions_by_sub:
-                yield oidc_session
+            yield from oidc_sessions_by_sub
