@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console module:
 #   Testscript for umc sanitizer
@@ -106,7 +105,7 @@ class Instance(Base):
     @simple_response
     @log
     def list(self, value):
-        assert isinstance(value, (list, tuple)), 'No List given'
+        assert isinstance(value, list | tuple), 'No List given'
         return '%r' % (value,)
 
     @sanitize(value=s.ListSanitizer(min_elements=3, max_elements=6, required=True))
@@ -117,7 +116,7 @@ class Instance(Base):
         return '%r' % (value,)
 
     _mapping = {
-        u'foo': 'bar',
+        'foo': 'bar',
         b'bar': 1,
         'baz': [],
     }
@@ -142,7 +141,7 @@ class Instance(Base):
     @simple_response
     @log
     def string(self, value):
-        assert isinstance(value, (str, bytes))
+        assert isinstance(value, str | bytes)
         if not isinstance(value, str):
             # Is it possible that we don't have unicode here?
             try:
