@@ -92,6 +92,7 @@ define([
 	var _initialHash = decodeURIComponent(dojoHash());
 	var _overviewVisible = true;
 	var _menuVisible = true;
+	var _headerTryHide = false;
 
 	// helper function for sorting, sort indices with priority < 0 to be at the end
 	var _cmpPriority = function(x, y) {
@@ -442,161 +443,8 @@ define([
 			}
 		};
 
-		var summit2021DialogWasShown = true;
-		var showSummit2021Dialog = function() {
-			var endOfSummit = new Date(2021, 0, 28, 0, 0, 0);
-			var summitHasPassed = endOfSummit < new Date();
-			var isUserAdmin = app.getModule('updater') || app.getModule('schoolrooms');
-			var dontShowDialog = !tools.status('has_free_license') || summitHasPassed || !isUserAdmin || cookie('hideSummit2021Dialog');
-			if (dontShowDialog) {
-				summit2021DialogWasShown = false;
-				return;
-			}
-
-			var title = '' +
-				'<div>' +
-					'<p class="umcSummit2021Dialog__header-text">' +
-						'Univention Summit 2021' +
-					'</p>' +
-				'</div>';
-
-			var message_base = '' +
-				'<div class="umcSummit2021Message">' +
-					'<div class="umcSummit2021Message__messageWrapper">' +
-						'{0}' +
-						'<ul>' +
-							'<li>{1}</li>' +
-							'<li>{2}</li>' +
-							'<li>{3}</li>' +
-							'<li>{4}</li>' +
-							'<li>{5}</li>' +
-							'<li>{6}</li>' +
-							'<li>{7}</li>' +
-						'</ul>' +
-						'<a class="umcSummit2021Message__link" href="{8}" target="_blank">{9}</a>' +
-					'</div>' +
-					'<div class="umcSummit2021Message__image">' +
-					'</div>' +
-				'</div>';
-			var message_de = lang.replace(message_base, [
-				title,
-				'Virtual Venue am 28. Januar 2021',
-				'500 Teilnehmende',
-				'25 Aussteller & Sponsoren',
-				'Keynotes, Workshops, Round Tables & Praxisvorträge',
-				'Roadmap: UCS 5 und UCS@school 5',
-				'Digitale Souveränität: Phoenix, Gaia X und SCS',
-				'Digitale Bildung: Bildungs-Cloud, Schulportale und IT-Lösungen',
-				'https://www.univention-summit.de/?pk_campaign=Summit21-UMC-Popup',
-				'Jetzt registrieren'
-			]);
-
-			var message_en = lang.replace(message_base, [
-				title,
-				'Virtual Venue on January 28, 2021',
-				'500 Attendees',
-				'25 Exhibitors & Sponsors',
-				'Keynotes, Workshops, Round Tables & Best Practices',
-				'Roadmap: UCS 5 and UCS@school 5',
-				'Digital Sovereignty: Phoenix, Gaia X and SCS',
-				'Digital Education: Educational Cloud, School Portals and IT Solutions',
-				'https://www.univention-summit.com/?pk_campaign=Summit21-UMC-Popup',
-				'Register now'
-			]);
-
-			var isDE = (kernel.locale.toLowerCase().indexOf('de') === 0);
-			var message = isDE ? message_de : message_en;
-
-			var options = [{
-				'label': 'OK',
-				'default': true
-			}];
-
-			// preload the image and then show dialog
-			var img = new Image();
-			on(img, ['load', 'error'], function() {
-				img = null; // garbage collect the img
-
-				var dialog = new ConfirmDialog({
-					'class': 'umcSummit2021Dialog',
-					title: title,
-					message: message,
-					options: options,
-				});
-				on(dialog, 'confirm', function() {
-					var nowInTwoWeeks = new Date(Date.now() + (1000 * 60 * 60 * 24 * 14));
-					var expires = nowInTwoWeeks < endOfSummit ? nowInTwoWeeks : endOfSummit;
-					cookie('hideSummit2021Dialog', 'true', {expires: expires.toUTCString()});
-					dialog.close();
-				});
-				dialog.show();
-			});
-			img.src = '/univention/management/univention-summit-2021.svg';
-		};
-
-		var showSummit2021Notification = function() {
-			if (summit2021DialogWasShown) {
-				return;
-			}
-
-			var endOfSummit = new Date(2021, 0, 28, 0, 0, 0);
-			var summitHasPassed = endOfSummit < new Date();
-			var isUserAdmin = app.getModule('updater') || app.getModule('schoolrooms');
-			var dontShowNotification = !tools.status('has_free_license') || summitHasPassed || !isUserAdmin || cookie('hideSummit2021Notification');
-			if (dontShowNotification) {
-				return;
-			}
-
-			var isDE = (kernel.locale.toLowerCase().indexOf('de') === 0);
-			var message_de = '<a href="https://www.univention-summit.de/?pk_campaign=Summit20-UMC-Nachricht" target="_blank">Univention Summit 2021</a> - Anwender, OS-Hersteller & Univention treffen und alles zu UCS 5 & Best Practices erfahren.';
-			var message_en = '<a href="https://www.univention-summit.com/?pk_campaign=Summit20-UMC-Nachricht" target="_blank">Univention Summit 2021</a> - Meet users, OS vendors & Univention and learn all about UCS 5 & Best Practices. ';
-			var message = isDE ? message_de : message_en;
-			dialog.notify(message).then(function(notification) {
-				on(notification, 'remove', function() {
-					var nowInTwoWeeks = new Date(Date.now() + (1000 * 60 * 60 * 24 * 14));
-					var expires = nowInTwoWeeks < endOfSummit ? nowInTwoWeeks : endOfSummit;
-					cookie('hideSummit2021Notification', 'true', {expires: expires.toUTCString()});
-				});
-			});
-		};
-
-		var showAmbassadorNotification = function() {
-			var endOfAmbassadorProgram = new Date(2019, 7, 14, 0, 0, 0);
-			var ambassadorProgramHasPassed = endOfAmbassadorProgram < new Date();
-			var isUserAdmin = app.getModule('updater') || app.getModule('schoolrooms');
-			var dontShowNotification = !tools.status('has_free_license') || ambassadorProgramHasPassed || !isUserAdmin || cookie('hideAmbassadorNotification');
-			if (dontShowNotification) {
-				return;
-			}
-
-			var message = 'Write a comment, a short review, or a tutorial about UCS and collect valuable bonus points as a UCS Ambassador. More information: <a href="http://bit.ly/UCS_Ambassador_Program" target="_blank" rel="noopener">UCS Ambassador Program</a>';
-			var title = 'UCS Ambassador Program';
-			switch (i18nTools.defaultLang().substring(0, 2)) {
-				case 'de':
-					message = 'Jetzt Kommentar, kurzes Review oder Tutorial zu UCS schreiben und als UCS Ambassador wertvolle Bonuspunkte sammeln! Mehr Infos: <a href="http://bit.ly/UCS_Ambassador" target="_blank" rel="noopener">UCS Ambassador Programm</a>';
-					title = 'UCS Ambassador Programm';
-					break;
-				case 'fr':
-					message = 'Écrivez un commentaire, une courte critique ou un tutoriel sur UCS et accumulez de précieux points en prime en tant qu\'ambassadeur de UCS! Plus d\'info: <a href="http://bit.ly/UCS_Ambassador_Program_France" target="_blank" rel="noopener">Programme des ambassadeurs de UCS</a>';
-					title = 'Programme des ambassadeurs de UCS';
-					break;
-			}
-
-			dialog.notify(message, title, false).then(function(notification) {
-				on(notification, 'remove', function() {
-					// make sure that the cookie does not expire too early
-					var expires = new Date(endOfAmbassadorProgram);
-					expires.setDate(expires.getDate() + 7);
-					cookie('hideAmbassadorNotification', 'true', {expires: expires.toUTCString()});
-				});
-			});
-		};
-
 		// run several checks
 		checkCertificateValidity();
-		showSummit2021Dialog();
-		showSummit2021Notification();
-		showAmbassadorNotification();
 	});
 
 	var UmcHeader = declare([ContainerWidget], {
@@ -638,12 +486,33 @@ define([
 			if (_overviewVisible) {
 				this.setupSearchField();
 			}
-			this._headerRight.addChild(new NotificationsButton({}));
+			this.notificationsButton = new NotificationsButton({});
+			on(this.notificationsButton.notificationsContainer, 'countChanged', lang.hitch(this, function(count) {
+				tools.status('numOfNotifications', count);
+				this._updateHeader();
+			}))
+			this._headerRight.addChild(this.notificationsButton);
 			if (_menuVisible) {
 				this._headerRight.addChild(new MenuButton({}));
 			}
 		},
 
+		_updateHeader: function() {
+			if (!_headerTryHide) {
+				return;
+			}
+
+			var hasNotifications = tools.status('numOfNotifications') > 0;
+			domClass.toggle(this.notificationsButton.domNode, 'dijitDisplayNone', !hasNotifications);
+			if (!hasNotifications) {
+				this.notificationsButton.set('checked', false);
+			}
+
+			var hasTabs = tools.status('numOfTabs') > 0;
+			var hideHeader = !hasNotifications && !hasTabs;
+			domClass.toggle(this.domNode, 'umcHeader--hidden', hideHeader);
+		},
+
 		mobileTabsView: false,
 		_setMobileTabsViewAttr: function(isTrue) {
 			tools.toggleVisibility(this._tabController, !isTrue);
@@ -897,15 +766,15 @@ define([
 		buildRendering: function() {
 			this.inherited(arguments);
 			domClass.add(this.domNode, 'umcModuleTab');
+			if (!_headerTryHide) {
+				var backgroundNode = put('div.umcModuleTab__background');
+				domConstruct.place(backgroundNode, this.domNode, 'first');
+				var nodeLeft = domConstruct.toDom('<svg class="umcModuleTab__background__svg umcModuleTab__background__svg--left" viewBox="0 0 100 100"><path d="M0,100 L100,100 L100,0 Q 85 85 0 100 z" /></svg>');
+				domConstruct.place(nodeLeft, backgroundNode);
 
-			var backgroundNode = put('div.umcModuleTab__background');
-			domConstruct.place(backgroundNode, this.domNode, 'first');
-			var nodeLeft = domConstruct.toDom('<svg class="umcModuleTab__background__svg umcModuleTab__background__svg--left" viewBox="0 0 100 100"><path d="M0,100 L100,100 L100,0 Q 85 85 0 100 z" /></svg>');
-			domConstruct.place(nodeLeft, backgroundNode);
-
-			var nodeRight = domConstruct.toDom('<svg class="umcModuleTab__background__svg umcModuleTab__background__svg--right" viewBox="0 0 100 100"><path d="M0,0 Q 15 85 100 100  L 0,100 z" /></svg>');
-			domConstruct.place(nodeRight, backgroundNode);
-
+				var nodeRight = domConstruct.toDom('<svg class="umcModuleTab__background__svg umcModuleTab__background__svg--right" viewBox="0 0 100 100"><path d="M0,0 Q 15 85 100 100  L 0,100 z" /></svg>');
+				domConstruct.place(nodeRight, backgroundNode);
+			}
 			var closeButtonNode = Button.simpleIconButtonNode('x', 'umcModuleTab__closeButton');
 			put(this.closeNode, '+', closeButtonNode);
 			put(this.closeNode, '!');
@@ -921,9 +790,11 @@ define([
 			//		The following properties may be given:
 			//		* username, password: if both values are given, the UMC tries to directly
 			//		  with these credentials.
-			//		* overview (Boolean): Specifies whether or not the overview of available modules
-			//		                      and the search is displayed or not. (detault: true)
-			//		* menu (Boolean): Specifies whether or not the hamburger menu is displayed. (default: true)
+			//		* overview (Boolean): Specifies whether the overview of available modules
+			//		  and the search is displayed or not. (detault: true)
+			//		* menu (Boolean): Specifies whether the hamburger menu is displayed. (default: true)
+			//		* header: Can be set to 'try-hide'. When UMC modules are opened in an iframe this
+			//		  property is used to apply special behavior to the UMC header.
 
 			// username will be overridden by final authenticated username
 			tools.status('username', props.username || tools.status('username'));
@@ -938,6 +809,13 @@ define([
 				_menuVisible = tools.isTrue(props.menu);
 			}
 
+			if (props.header === 'try-hide') {
+				if(!tools.isTrue(props.menu) && !tools.isTrue(props.overview)) {
+					_headerTryHide = true;
+				}
+			}
+
+
 			login.onInitialLogin(lang.hitch(this, '_authenticated'));
 		},
 
@@ -971,6 +849,10 @@ define([
 				this.setupTouchDevices();
 			}
 
+			if (_headerTryHide) {
+				domClass.add(baseWin.body(), 'umcHeaderTryHide');
+			}
+
 			// set up fundamental layout parts...
 
 			this._topContainer = new ContainerWidget({
@@ -1001,6 +883,7 @@ define([
 				_tabContainer: this._tabContainer,
 				switchToOverview: lang.hitch(this, 'switchToOverview')
 			});
+			domClass.toggle(this._header.domNode, 'umcHeader--hidden', _headerTryHide);
 
 			this.registerTabSwitchHandling();
 
@@ -1067,6 +950,7 @@ define([
 			}));
 			aspect.before(this._tabContainer, 'removeChild', lang.hitch(this, function(module) {
 				this._updateNumOfTabs(-1);
+				this._header._updateHeader();
 				topic.publish('/umc/actions', module.moduleID, module.moduleFlavor, 'close');
 
 				if (module === this._tabContainer.get('selectedChildWidget')) {
@@ -1306,7 +1190,7 @@ define([
 			// set window title
 			window.document.title = tools.status('title') || lang.replace('{0} - {1}', [tools.status('fqdn'), window.document.title]);
 			if (tools.status('favicon')) {
-			    (query('link[rel="shortcut icon"]')[0] || query('link[rel="icon"]')[0] || {}).href = tools.status('favicon');
+				(query('link[rel="shortcut icon"]')[0] || query('link[rel="icon"]')[0] || {}).href = tools.status('favicon');
 			}
 
 			// setup menus
@@ -1649,7 +1533,8 @@ define([
 
 					var params = lang.mixin({
 						title: module.name,
-						//iconClass: tools.getIconClass(module.icon),
+						icon: module.icon,
+						iconBackgroundColor: this.__getModuleColor(module),
 						closable: closable,
 						moduleFlavor: module.flavor,
 						moduleID: module.id,
@@ -1662,6 +1547,7 @@ define([
 					this._tabContainer.addChild(tab);
 					tab.startup();
 					this._updateNumOfTabs();
+					this._header._updateHeader();
 					this.__insertTabStyles(tab, module);
 					topic.publish('/umc/actions', module.id, module.flavor, 'open');
 					tools.checkReloadRequired();
